Parameters — miml documentation

Skip to main content
`Ctrl`+`K`

# Parameters

miml.datasets.dataset_utils.arff_to_csv(file: str) → None

  Convert MIML Arff to CSV.

  # Parameters

  filestr

    Filepath of the file to be converted

miml.datasets.dataset_utils.load_birds()

  Load birds dataset from package

  # Returns

  datasetMIMLDataset

    Dataset loaded

miml.datasets.dataset_utils.load_birds_test()

  Load a test partition of birds dataset from package

  # Returns

  datasetMIMLDataset

    Dataset loaded

miml.datasets.dataset_utils.load_birds_train()

  Load a train partition of birds dataset from package

  # Returns

  datasetMIMLDataset

    Dataset loaded

miml.datasets.dataset_utils.load_dataset(file: str) → MIMLDataset

  Function to load a dataset

  # Parameters

  filestr

    Path of the dataset file

  # Returns

  datasetMIMLDataset

    Dataset loaded

miml.datasets.dataset_utils.load_dataset_arff(file: str) → MIMLDataset

  Function to load a dataset in arff format

  # Parameters

  filestr

    Path of the dataset file

  # Returns

  datasetMIMLDataset

    Dataset loaded

miml.datasets.dataset_utils.load_dataset_csv(file: str)

  Function to load a dataset in csv format

  # Parameters

  filestr

    Path of the dataset file

  # Returns

  datasetMIMLDataset

    Dataset loaded

miml.datasets.dataset_utils.load_toy()

  Load toy dataset from package

  # Returns

  datasetMIMLDataset

    Dataset loaded